==> haskell-rate-limit-1.4.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rate-limit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rate-limit
version:              1.4.2
visibility:           public
id:                   rate-limit-1.4.2-G0JBGFJfmHtLOCTMYA1m1B
key:                  rate-limit-1.4.2-G0JBGFJfmHtLOCTMYA1m1B
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/rate-limit
synopsis:             A basic library for rate-limiting IO actions.
description:
    In many cases, it is useful, necessary, or simply nice to limit how
    frequently you perform some action. For example, you may want to limit
    how often your program makes a request of some web site. This library
    is intended as a general-purpose mechanism for rate-limiting IO actions.

category:             Control
abi:                  0cce107d59b901eb09f97cf39f1631a5
exposed:              True
exposed-modules:      Control.RateLimit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/rate-limit-1.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rate-limit-1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rate-limit
hs-libraries:         HSrate-limit-1.4.2-G0JBGFJfmHtLOCTMYA1m1B
depends:
    base-4.15.1.0 stm-2.5.0.0 time-1.9.3
    time-units-1.0.0-D1nYXpAWCQ2FSIdA8ibzEx

haddock-interfaces:   /usr/share/doc/haskell-rate-limit/html/rate-limit.haddock
haddock-html:         /usr/share/doc/haskell-rate-limit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rate-limit-1.4.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rate-limit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rate-limit
version:              1.4.3
visibility:           public
id:                   rate-limit-1.4.3-85YmVCfT47Z7hrGUe8KO44
key:                  rate-limit-1.4.3-85YmVCfT47Z7hrGUe8KO44
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/rate-limit
synopsis:             A basic library for rate-limiting IO actions.
description:
    In many cases, it is useful, necessary, or simply nice to limit how
    frequently you perform some action. For example, you may want to limit
    how often your program makes a request of some web site. This library
    is intended as a general-purpose mechanism for rate-limiting IO actions.

category:             Control
abi:                  737b804456f9aed57b710cd6b1fc94dd
exposed:              True
exposed-modules:      Control.RateLimit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/rate-limit-1.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rate-limit-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rate-limit
hs-libraries:         HSrate-limit-1.4.3-85YmVCfT47Z7hrGUe8KO44
depends:
    base-4.15.1.0 stm-2.5.0.0 time-1.9.3
    time-units-1.0.0-D1nYXpAWCQ2FSIdA8ibzEx

haddock-interfaces:   /usr/share/doc/haskell-rate-limit/html/rate-limit.haddock
haddock-html:         /usr/share/doc/haskell-rate-limit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
